# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/compute/v1/instancegroup/instance_group.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/compute/v1/instancegroup/instance_group.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:yandex/cloud/compute/v1/instancegroup/instance_group.proto\x12%yandex.cloud.compute.v1.instancegroup\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\x92\x0c\n\rInstanceGroup\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12P\n\x06labels\x18\x06 \x03(\x0b\x32@.yandex.cloud.compute.v1.instancegroup.InstanceGroup.LabelsEntry\x12R\n\x11instance_template\x18\x07 \x01(\x0b\x32\x37.yandex.cloud.compute.v1.instancegroup.InstanceTemplate\x12H\n\x0cscale_policy\x18\x08 \x01(\x0b\x32\x32.yandex.cloud.compute.v1.instancegroup.ScalePolicy\x12J\n\rdeploy_policy\x18\t \x01(\x0b\x32\x33.yandex.cloud.compute.v1.instancegroup.DeployPolicy\x12R\n\x11\x61llocation_policy\x18\n \x01(\x0b\x32\x37.yandex.cloud.compute.v1.instancegroup.AllocationPolicy\x12U\n\x13load_balancer_state\x18\x0b \x01(\x0b\x32\x38.yandex.cloud.compute.v1.instancegroup.LoadBalancerState\x12]\n\x17managed_instances_state\x18\x0c \x01(\x0b\x32<.yandex.cloud.compute.v1.instancegroup.ManagedInstancesState\x12S\n\x12load_balancer_spec\x18\x0e \x01(\x0b\x32\x37.yandex.cloud.compute.v1.instancegroup.LoadBalancerSpec\x12S\n\x12health_checks_spec\x18\x0f \x01(\x0b\x32\x37.yandex.cloud.compute.v1.instancegroup.HealthChecksSpec\x12\x1a\n\x12service_account_id\x18\x10 \x01(\t\x12K\n\x06status\x18\x11 \x01(\x0e\x32;.yandex.cloud.compute.v1.instancegroup.InstanceGroup.Status\x12\x42\n\tvariables\x18\x12 \x03(\x0b\x32/.yandex.cloud.compute.v1.instancegroup.Variable\x12\x1b\n\x13\x64\x65letion_protection\x18\x13 \x01(\x08\x12j\n\x1e\x61pplication_load_balancer_spec\x18\x14 \x01(\x0b\x32\x42.yandex.cloud.compute.v1.instancegroup.ApplicationLoadBalancerSpec\x12l\n\x1f\x61pplication_load_balancer_state\x18\x15 \x01(\x0b\x32\x43.yandex.cloud.compute.v1.instancegroup.ApplicationLoadBalancerState\x12U\n\x13\x61uto_healing_policy\x18\x16 \x01(\x0b\x32\x38.yandex.cloud.compute.v1.instancegroup.AutoHealingPolicy\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"o\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08STARTING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08STOPPING\x10\x03\x12\x0b\n\x07STOPPED\x10\x04\x12\x0c\n\x08\x44\x45LETING\x10\x05\x12\n\n\x06PAUSED\x10\x06J\x04\x08\r\x10\x0e\"O\n\x1c\x41pplicationLoadBalancerState\x12\x17\n\x0ftarget_group_id\x18\x01 \x01(\t\x12\x16\n\x0estatus_message\x18\x02 \x01(\t\"O\n\x08Variable\x12)\n\x03key\x18\x01 \x01(\tB\x1c\xf2\xc7\x31\x0f[a-zA-Z0-9._-]*\x8a\xc8\x31\x05\x31-128\x12\x18\n\x05value\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=128\"D\n\x11LoadBalancerState\x12\x17\n\x0ftarget_group_id\x18\x01 \x01(\t\x12\x16\n\x0estatus_message\x18\x02 \x01(\t\"\xc5\x02\n\x15ManagedInstancesState\x12\x13\n\x0btarget_size\x18\x01 \x01(\x03\x12\x1c\n\x14running_actual_count\x18\x04 \x01(\x03\x12\x1e\n\x16running_outdated_count\x18\x05 \x01(\x03\x12\x18\n\x10processing_count\x18\x06 \x01(\x03\x1a\xb8\x01\n\x08Statuses\x12\x10\n\x08\x63reating\x18\x01 \x01(\x03\x12\x10\n\x08starting\x18\x02 \x01(\x03\x12\x0f\n\x07opening\x18\x03 \x01(\x03\x12\x0f\n\x07warming\x18\x04 \x01(\x03\x12\x0f\n\x07running\x18\x05 \x01(\x03\x12\x0f\n\x07\x63losing\x18\x06 \x01(\x03\x12\x10\n\x08stopping\x18\x07 \x01(\x03\x12\x10\n\x08updating\x18\x08 \x01(\x03\x12\x10\n\x08\x64\x65leting\x18\t \x01(\x03\x12\x0e\n\x06\x66\x61iled\x18\n \x01(\x03J\x04\x08\x02\x10\x04\"\x96\x0e\n\x0bScalePolicy\x12T\n\x0b\x66ixed_scale\x18\x01 \x01(\x0b\x32=.yandex.cloud.compute.v1.instancegroup.ScalePolicy.FixedScaleH\x00\x12R\n\nauto_scale\x18\x02 \x01(\x0b\x32<.yandex.cloud.compute.v1.instancegroup.ScalePolicy.AutoScaleH\x00\x12U\n\x0ftest_auto_scale\x18\x03 \x01(\x0b\x32<.yandex.cloud.compute.v1.instancegroup.ScalePolicy.AutoScale\x1a\xa7\x05\n\tAutoScale\x12 \n\rmin_zone_size\x18\x01 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\x12\x1b\n\x08max_size\x18\x02 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\x12\x43\n\x14measurement_duration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\xc7\x31\x06\x31m-10m\x12=\n\x0fwarmup_duration\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationB\t\xfa\xc7\x31\x05<=10m\x12\x45\n\x16stabilization_duration\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\xc7\x31\x06\x31m-30m\x12\x1d\n\x0cinitial_size\x18\x06 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=1\x12\x63\n\x14\x63pu_utilization_rule\x18\x07 \x01(\x0b\x32\x45.yandex.cloud.compute.v1.instancegroup.ScalePolicy.CpuUtilizationRule\x12\\\n\x0c\x63ustom_rules\x18\x08 \x03(\x0b\x32=.yandex.cloud.compute.v1.instancegroup.ScalePolicy.CustomRuleB\x07\x82\xc8\x31\x03<=3\x12\x63\n\x0f\x61uto_scale_type\x18\t \x01(\x0e\x32J.yandex.cloud.compute.v1.instancegroup.ScalePolicy.AutoScale.AutoScaleType\"I\n\rAutoScaleType\x12\x1f\n\x1b\x41UTO_SCALE_TYPE_UNSPECIFIED\x10\x00\x12\t\n\x05ZONAL\x10\x01\x12\x0c\n\x08REGIONAL\x10\x02\x1a<\n\x12\x43puUtilizationRule\x12&\n\x12utilization_target\x18\x01 \x01(\x01\x42\n\xfa\xc7\x31\x06\x31\x30-100\x1a\xe2\x05\n\nCustomRule\x12_\n\trule_type\x18\x01 \x01(\x0e\x32\x46.yandex.cloud.compute.v1.instancegroup.ScalePolicy.CustomRule.RuleTypeB\x04\xe8\xc7\x31\x01\x12\x63\n\x0bmetric_type\x18\x02 \x01(\x0e\x32H.yandex.cloud.compute.v1.instancegroup.ScalePolicy.CustomRule.MetricTypeB\x04\xe8\xc7\x31\x01\x12O\n\x0bmetric_name\x18\x03 \x01(\tB:\xe8\xc7\x31\x01\xf2\xc7\x31\x32[a-zA-Z0-9./@_][ 0-9a-zA-Z./@_,:;()\\[\\]<>-]{0,198}\x12\xb3\x01\n\x06labels\x18\x05 \x03(\x0b\x32I.yandex.cloud.compute.v1.instancegroup.ScalePolicy.CustomRule.LabelsEntryBX\xf2\xc7\x31\x32[a-zA-Z0-9./@_][ 0-9a-zA-Z./@_,:;()\\[\\]<>-]{0,198}\xb2\xc8\x31\x1e\x12\x1c^[a-zA-Z][0-9a-zA-Z_]{0,31}$\x12\x16\n\x06target\x18\x04 \x01(\x01\x42\x06\xfa\xc7\x31\x02>0\x12\x1b\n\tfolder_id\x18\x06 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1a\n\x07service\x18\x07 \x01(\tB\t\x8a\xc8\x31\x05<=200\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"D\n\x08RuleType\x12\x19\n\x15RULE_TYPE_UNSPECIFIED\x10\x00\x12\x0f\n\x0bUTILIZATION\x10\x01\x12\x0c\n\x08WORKLOAD\x10\x02\"A\n\nMetricType\x12\x1b\n\x17METRIC_TYPE_UNSPECIFIED\x10\x00\x12\t\n\x05GAUGE\x10\x01\x12\x0b\n\x07\x43OUNTER\x10\x02\x1a%\n\nFixedScale\x12\x17\n\x04size\x18\x01 \x01(\x03\x42\t\xfa\xc7\x31\x05\x31-100B\x12\n\nscale_type\x12\x04\xc0\xc1\x31\x01\"\xb2\x04\n\x0c\x44\x65ployPolicy\x12\"\n\x0fmax_unavailable\x18\x01 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\x12\x1f\n\x0cmax_deleting\x18\x02 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\x12\x1f\n\x0cmax_creating\x18\x03 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\x12 \n\rmax_expansion\x18\x06 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\x12>\n\x10startup_duration\x18\x07 \x01(\x0b\x32\x19.google.protobuf.DurationB\t\xfa\xc7\x31\x05\x30m-1h\x12N\n\x08strategy\x18\x08 \x01(\x0e\x32<.yandex.cloud.compute.v1.instancegroup.DeployPolicy.Strategy\x12Y\n\x0eminimal_action\x18\x0e \x01(\x0e\x32\x41.yandex.cloud.compute.v1.instancegroup.DeployPolicy.MinimalAction\"F\n\x08Strategy\x12\x18\n\x14STRATEGY_UNSPECIFIED\x10\x00\x12\r\n\tPROACTIVE\x10\x01\x12\x11\n\rOPPORTUNISTIC\x10\x02\"[\n\rMinimalAction\x12\x1e\n\x1aMINIMAL_ACTION_UNSPECIFIED\x10\x00\x12\x0f\n\x0bLIVE_UPDATE\x10\x01\x12\x0b\n\x07RESTART\x10\x02\x12\x0c\n\x08RECREATE\x10\x03J\x04\x08\t\x10\x0eJ\x04\x08\x04\x10\x06\"\xb1\x01\n\x10\x41llocationPolicy\x12T\n\x05zones\x18\x01 \x03(\x0b\x32<.yandex.cloud.compute.v1.instancegroup.AllocationPolicy.ZoneB\x07\x82\xc8\x31\x03>=1\x1aG\n\x04Zone\x12\x15\n\x07zone_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12(\n\x12instance_tags_pool\x18\x02 \x03(\tB\x0c\x8a\xc8\x31\x04\x33-50\x90\xc8\x31\x01\"\xa7\n\n\x10InstanceTemplate\x12\x1e\n\x0b\x64\x65scription\x18\x01 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x86\x01\n\x06labels\x18\x02 \x03(\x0b\x32\x43.yandex.cloud.compute.v1.instancegroup.InstanceTemplate.LabelsEntryB1\x82\xc8\x31\x04<=64\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x19\n\x0bplatform_id\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12R\n\x0eresources_spec\x18\x04 \x01(\x0b\x32\x34.yandex.cloud.compute.v1.instancegroup.ResourcesSpecB\x04\xe8\xc7\x31\x01\x12\x8a\x01\n\x08metadata\x18\x05 \x03(\x0b\x32\x45.yandex.cloud.compute.v1.instancegroup.InstanceTemplate.MetadataEntryB1\x82\xc8\x31\x05<=128\x8a\xc8\x31\x08<=262144\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12U\n\x0e\x62oot_disk_spec\x18\x06 \x01(\x0b\x32\x37.yandex.cloud.compute.v1.instancegroup.AttachedDiskSpecB\x04\xe8\xc7\x31\x01\x12^\n\x14secondary_disk_specs\x18\x07 \x03(\x0b\x32\x37.yandex.cloud.compute.v1.instancegroup.AttachedDiskSpecB\x07\x82\xc8\x31\x03<=3\x12\x62\n\x17network_interface_specs\x18\x08 \x03(\x0b\x32;.yandex.cloud.compute.v1.instancegroup.NetworkInterfaceSpecB\x04\xe8\xc7\x31\x01\x12R\n\x11scheduling_policy\x18\t \x01(\x0b\x32\x37.yandex.cloud.compute.v1.instancegroup.SchedulingPolicy\x12\x1a\n\x12service_account_id\x18\n \x01(\t\x12P\n\x10network_settings\x18\x0b \x01(\x0b\x32\x36.yandex.cloud.compute.v1.instancegroup.NetworkSettings\x12\x17\n\x04name\x18\x0c \x01(\tB\t\x8a\xc8\x31\x05<=128\x12\x1b\n\x08hostname\x18\r \x01(\tB\t\x8a\xc8\x31\x05<=128\x12P\n\x10placement_policy\x18\x0e \x01(\x0b\x32\x36.yandex.cloud.compute.v1.instancegroup.PlacementPolicy\x12W\n\x10\x66ilesystem_specs\x18\x0f \x03(\x0b\x32=.yandex.cloud.compute.v1.instancegroup.AttachedFilesystemSpec\x12P\n\x10metadata_options\x18\x10 \x01(\x0b\x32\x36.yandex.cloud.compute.v1.instancegroup.MetadataOptions\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8f\x02\n\x16\x41ttachedFilesystemSpec\x12P\n\x04mode\x18\x01 \x01(\x0e\x32\x42.yandex.cloud.compute.v1.instancegroup.AttachedFilesystemSpec.Mode\x12/\n\x0b\x64\x65vice_name\x18\x02 \x01(\tB\x1a\xf2\xc7\x31\x16|[a-z][-_0-9a-z]{0,19}\x12\x35\n\rfilesystem_id\x18\x03 \x01(\tB\x1e\xf2\xc7\x31\x11[-a-zA-Z0-9._{}]*\x8a\xc8\x31\x05<=128\";\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\r\n\tREAD_ONLY\x10\x01\x12\x0e\n\nREAD_WRITE\x10\x02\"\xdd\x02\n\x0fPlacementPolicy\x12\x1a\n\x12placement_group_id\x18\x01 \x01(\t\x12\x64\n\x13host_affinity_rules\x18\x02 \x03(\x0b\x32G.yandex.cloud.compute.v1.instancegroup.PlacementPolicy.HostAffinityRule\x1a\xc7\x01\n\x10HostAffinityRule\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\\\n\x02op\x18\x02 \x01(\x0e\x32P.yandex.cloud.compute.v1.instancegroup.PlacementPolicy.HostAffinityRule.Operator\x12\x0e\n\x06values\x18\x03 \x03(\t\"8\n\x08Operator\x12\x18\n\x14OPERATOR_UNSPECIFIED\x10\x00\x12\x06\n\x02IN\x10\x01\x12\n\n\x06NOT_IN\x10\x02\"\xdf\x01\n\rResourcesSpec\x12\"\n\x06memory\x18\x01 \x01(\x03\x42\x12\xfa\xc7\x31\x0e<=824633720832\x12\x65\n\x05\x63ores\x18\x02 \x01(\x03\x42V\xfa\xc7\x31R2,4,6,8,10,12,14,16,18,20,22,24,26,28,30,32,34,36,40,44,48,52,56,60,64,68,72,76,80\x12(\n\rcore_fraction\x18\x03 \x01(\x03\x42\x11\xfa\xc7\x31\r0,5,20,50,100\x12\x19\n\x04gpus\x18\x04 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30,1,2,4\"\xe2\x04\n\x10\x41ttachedDiskSpec\x12P\n\x04mode\x18\x01 \x01(\x0e\x32<.yandex.cloud.compute.v1.instancegroup.AttachedDiskSpec.ModeB\x04\xe8\xc7\x31\x01\x12/\n\x0b\x64\x65vice_name\x18\x02 \x01(\tB\x1a\xf2\xc7\x31\x16|[a-z][-_0-9a-z]{0,19}\x12Y\n\tdisk_spec\x18\x03 \x01(\x0b\x32@.yandex.cloud.compute.v1.instancegroup.AttachedDiskSpec.DiskSpecB\x04\xe8\xc7\x31\x01\x12/\n\x07\x64isk_id\x18\x04 \x01(\tB\x1e\xf2\xc7\x31\x11[-a-zA-Z0-9._{}]*\x8a\xc8\x31\x05<=128\x12\x17\n\x04name\x18\x07 \x01(\tB\t\x8a\xc8\x31\x05<=128\x1a\xe2\x01\n\x08\x44iskSpec\x12\x1e\n\x0b\x64\x65scription\x18\x01 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x15\n\x07type_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12(\n\x04size\x18\x03 \x01(\x03\x42\x1a\xfa\xc7\x31\x16\x34\x31\x39\x34\x33\x30\x34-28587302322176\x12\x1c\n\x08image_id\x18\x04 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x1f\n\x0bsnapshot_id\x18\x05 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12&\n\x1epreserve_after_instance_delete\x18\x06 \x01(\x08\x42\x0e\n\x0csource_oneof\";\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\r\n\tREAD_ONLY\x10\x01\x12\x0e\n\nREAD_WRITE\x10\x02J\x04\x08\x05\x10\x07\"\x92\x02\n\x14NetworkInterfaceSpec\x12\x12\n\nnetwork_id\x18\x01 \x01(\t\x12\x12\n\nsubnet_ids\x18\x02 \x03(\t\x12Z\n\x17primary_v4_address_spec\x18\x03 \x01(\x0b\x32\x39.yandex.cloud.compute.v1.instancegroup.PrimaryAddressSpec\x12Z\n\x17primary_v6_address_spec\x18\x04 \x01(\x0b\x32\x39.yandex.cloud.compute.v1.instancegroup.PrimaryAddressSpec\x12\x1a\n\x12security_group_ids\x18\x05 \x03(\t\"\xca\x01\n\x12PrimaryAddressSpec\x12S\n\x13one_to_one_nat_spec\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.compute.v1.instancegroup.OneToOneNatSpec\x12N\n\x10\x64ns_record_specs\x18\x02 \x03(\x0b\x32\x34.yandex.cloud.compute.v1.instancegroup.DnsRecordSpec\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\"\xb8\x01\n\x0fOneToOneNatSpec\x12\x44\n\nip_version\x18\x01 \x01(\x0e\x32\x30.yandex.cloud.compute.v1.instancegroup.IpVersion\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12N\n\x10\x64ns_record_specs\x18\x03 \x03(\x0b\x32\x34.yandex.cloud.compute.v1.instancegroup.DnsRecordSpec\"_\n\rDnsRecordSpec\x12\x12\n\x04\x66qdn\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x13\n\x0b\x64ns_zone_id\x18\x02 \x01(\t\x12\x18\n\x03ttl\x18\x03 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30-86400\x12\x0b\n\x03ptr\x18\x04 \x01(\x08\"\'\n\x10SchedulingPolicy\x12\x13\n\x0bpreemptible\x18\x01 \x01(\x08\"\xbc\x01\n\x0fNetworkSettings\x12I\n\x04type\x18\x01 \x01(\x0e\x32;.yandex.cloud.compute.v1.instancegroup.NetworkSettings.Type\"^\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x0c\n\x08STANDARD\x10\x01\x12\x18\n\x14SOFTWARE_ACCELERATED\x10\x02\x12\x18\n\x14HARDWARE_ACCELERATED\x10\x03\"\xd4\x01\n\x10LoadBalancerSpec\x12Q\n\x11target_group_spec\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.compute.v1.instancegroup.TargetGroupSpec\x12I\n\x1cmax_opening_traffic_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\xc7\x31\x04>=1s\x12\x1c\n\x14ignore_health_checks\x18\x04 \x01(\x08J\x04\x08\x03\x10\x04\"\xae\x02\n\x0fTargetGroupSpec\x12\x32\n\x04name\x18\x01 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x97\x01\n\x06labels\x18\x03 \x03(\x0b\x32\x42.yandex.cloud.compute.v1.instancegroup.TargetGroupSpec.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xea\x01\n\x1b\x41pplicationLoadBalancerSpec\x12\x62\n\x11target_group_spec\x18\x01 \x01(\x0b\x32\x41.yandex.cloud.compute.v1.instancegroup.ApplicationTargetGroupSpecB\x04\xe8\xc7\x31\x01\x12I\n\x1cmax_opening_traffic_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\xc7\x31\x04>=1s\x12\x1c\n\x14ignore_health_checks\x18\x03 \x01(\x08\"\xcd\x01\n\x1a\x41pplicationTargetGroupSpec\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12]\n\x06labels\x18\x03 \x03(\x0b\x32M.yandex.cloud.compute.v1.instancegroup.ApplicationTargetGroupSpec.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xba\x01\n\x10HealthChecksSpec\x12[\n\x12health_check_specs\x18\x01 \x03(\x0b\x32\x36.yandex.cloud.compute.v1.instancegroup.HealthCheckSpecB\x07\x82\xc8\x31\x03>=1\x12I\n\x1cmax_checking_health_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\xc7\x31\x04>=1s\"\xa4\x04\n\x0fHealthCheckSpec\x12\x38\n\x08interval\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0b\xfa\xc7\x31\x07\x31s-300s\x12\x36\n\x07timeout\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\xc7\x31\x06\x31s-60s\x12\x35\n\x13unhealthy_threshold\x18\x03 \x01(\x03\x42\x18\xfa\xc7\x31\x14\x30,2,3,4,5,6,7,8,9,10\x12\x33\n\x11healthy_threshold\x18\x04 \x01(\x03\x42\x18\xfa\xc7\x31\x14\x30,2,3,4,5,6,7,8,9,10\x12X\n\x0btcp_options\x18\x05 \x01(\x0b\x32\x41.yandex.cloud.compute.v1.instancegroup.HealthCheckSpec.TcpOptionsH\x00\x12Z\n\x0chttp_options\x18\x06 \x01(\x0b\x32\x42.yandex.cloud.compute.v1.instancegroup.HealthCheckSpec.HttpOptionsH\x00\x1a\'\n\nTcpOptions\x12\x19\n\x04port\x18\x01 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x31-65535\x1a\x36\n\x0bHttpOptions\x12\x19\n\x04port\x18\x01 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x31-65535\x12\x0c\n\x04path\x18\x02 \x01(\tB\x1c\n\x14health_check_options\x12\x04\xc0\xc1\x31\x01\"\xdd\x05\n\x0fManagedInstance\x12\n\n\x02id\x18\x01 \x01(\t\x12M\n\x06status\x18\x02 \x01(\x0e\x32=.yandex.cloud.compute.v1.instancegroup.ManagedInstance.Status\x12\x13\n\x0binstance_id\x18\x03 \x01(\t\x12\x0c\n\x04\x66qdn\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x16\n\x0estatus_message\x18\x06 \x01(\t\x12\x0f\n\x07zone_id\x18\x07 \x01(\t\x12S\n\x12network_interfaces\x18\x08 \x03(\x0b\x32\x37.yandex.cloud.compute.v1.instancegroup.NetworkInterface\x12\x35\n\x11status_changed_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0cinstance_tag\x18\x0e \x01(\t\"\xec\x02\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x15\n\x11\x43REATING_INSTANCE\x10\x0b\x12\x15\n\x11UPDATING_INSTANCE\x10\x0c\x12\x15\n\x11\x44\x45LETING_INSTANCE\x10\r\x12\x15\n\x11STARTING_INSTANCE\x10\x0e\x12\x15\n\x11STOPPING_INSTANCE\x10\x0f\x12\x1d\n\x19\x41WAITING_STARTUP_DURATION\x10\x10\x12\x13\n\x0f\x43HECKING_HEALTH\x10\x11\x12\x13\n\x0fOPENING_TRAFFIC\x10\x12\x12\x1c\n\x18\x41WAITING_WARMUP_DURATION\x10\x13\x12\x13\n\x0f\x43LOSING_TRAFFIC\x10\x14\x12\x12\n\x0eRUNNING_ACTUAL\x10\x15\x12\x14\n\x10RUNNING_OUTDATED\x10\x16\x12\x0b\n\x07STOPPED\x10\x17\x12\x0b\n\x07\x44\x45LETED\x10\x18\x12\x17\n\x13PREPARING_RESOURCES\x10\x19J\x04\x08\n\x10\x0e\"\xef\x01\n\x10NetworkInterface\x12\r\n\x05index\x18\x01 \x01(\t\x12\x13\n\x0bmac_address\x18\x02 \x01(\t\x12\x11\n\tsubnet_id\x18\x03 \x01(\t\x12Q\n\x12primary_v4_address\x18\x04 \x01(\x0b\x32\x35.yandex.cloud.compute.v1.instancegroup.PrimaryAddress\x12Q\n\x12primary_v6_address\x18\x05 \x01(\x0b\x32\x35.yandex.cloud.compute.v1.instancegroup.PrimaryAddress\"\xb4\x01\n\x0ePrimaryAddress\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12J\n\x0eone_to_one_nat\x18\x02 \x01(\x0b\x32\x32.yandex.cloud.compute.v1.instancegroup.OneToOneNat\x12\x45\n\x0b\x64ns_records\x18\x03 \x03(\x0b\x32\x30.yandex.cloud.compute.v1.instancegroup.DnsRecord\"\xab\x01\n\x0bOneToOneNat\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x44\n\nip_version\x18\x02 \x01(\x0e\x32\x30.yandex.cloud.compute.v1.instancegroup.IpVersion\x12\x45\n\x0b\x64ns_records\x18\x03 \x03(\x0b\x32\x30.yandex.cloud.compute.v1.instancegroup.DnsRecord\"[\n\tDnsRecord\x12\x12\n\x04\x66qdn\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x13\n\x0b\x64ns_zone_id\x18\x02 \x01(\t\x12\x18\n\x03ttl\x18\x03 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30-86400\x12\x0b\n\x03ptr\x18\x04 \x01(\x08\"K\n\tLogRecord\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07message\x18\x02 \x01(\t\"\xdb\x01\n\x11\x41utoHealingPolicy\x12g\n\x13\x61uto_healing_action\x18\x01 \x01(\x0e\x32J.yandex.cloud.compute.v1.instancegroup.AutoHealingPolicy.AutoHealingAction\"]\n\x11\x41utoHealingAction\x12#\n\x1f\x41UTO_HEALING_ACTION_UNSPECIFIED\x10\x00\x12\x0b\n\x07RESTART\x10\x01\x12\x0c\n\x08RECREATE\x10\x02\x12\x08\n\x04NONE\x10\x03\"\xd9\x02\n\x0fMetadataOptions\x12P\n\x11gce_http_endpoint\x18\x01 \x01(\x0e\x32\x35.yandex.cloud.compute.v1.instancegroup.MetadataOption\x12S\n\x14\x61ws_v1_http_endpoint\x18\x02 \x01(\x0e\x32\x35.yandex.cloud.compute.v1.instancegroup.MetadataOption\x12M\n\x0egce_http_token\x18\x03 \x01(\x0e\x32\x35.yandex.cloud.compute.v1.instancegroup.MetadataOption\x12P\n\x11\x61ws_v1_http_token\x18\x04 \x01(\x0e\x32\x35.yandex.cloud.compute.v1.instancegroup.MetadataOption*;\n\tIpVersion\x12\x1a\n\x16IP_VERSION_UNSPECIFIED\x10\x00\x12\x08\n\x04IPV4\x10\x01\x12\x08\n\x04IPV6\x10\x02*L\n\x0eMetadataOption\x12\x1f\n\x1bMETADATA_OPTION_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\x42\x84\x01\n)yandex.cloud.api.compute.v1.instancegroupZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1/instancegroup;instancegroupb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)yandex.cloud.api.compute.v1.instancegroupZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1/instancegroup;instancegroup'
  _globals['_INSTANCEGROUP_LABELSENTRY']._loaded_options = None
  _globals['_INSTANCEGROUP_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_VARIABLE'].fields_by_name['key']._loaded_options = None
  _globals['_VARIABLE'].fields_by_name['key']._serialized_options = b'\362\3071\017[a-zA-Z0-9._-]*\212\3101\0051-128'
  _globals['_VARIABLE'].fields_by_name['value']._loaded_options = None
  _globals['_VARIABLE'].fields_by_name['value']._serialized_options = b'\212\3101\005<=128'
  _globals['_SCALEPOLICY_AUTOSCALE'].fields_by_name['min_zone_size']._loaded_options = None
  _globals['_SCALEPOLICY_AUTOSCALE'].fields_by_name['min_zone_size']._serialized_options = b'\372\3071\0050-100'
  _globals['_SCALEPOLICY_AUTOSCALE'].fields_by_name['max_size']._loaded_options = None
  _globals['_SCALEPOLICY_AUTOSCALE'].fields_by_name['max_size']._serialized_options = b'\372\3071\0050-100'
  _globals['_SCALEPOLICY_AUTOSCALE'].fields_by_name['measurement_duration']._loaded_options = None
  _globals['_SCALEPOLICY_AUTOSCALE'].fields_by_name['measurement_duration']._serialized_options = b'\372\3071\0061m-10m'
  _globals['_SCALEPOLICY_AUTOSCALE'].fields_by_name['warmup_duration']._loaded_options = None
  _globals['_SCALEPOLICY_AUTOSCALE'].fields_by_name['warmup_duration']._serialized_options = b'\372\3071\005<=10m'
  _globals['_SCALEPOLICY_AUTOSCALE'].fields_by_name['stabilization_duration']._loaded_options = None
  _globals['_SCALEPOLICY_AUTOSCALE'].fields_by_name['stabilization_duration']._serialized_options = b'\372\3071\0061m-30m'
  _globals['_SCALEPOLICY_AUTOSCALE'].fields_by_name['initial_size']._loaded_options = None
  _globals['_SCALEPOLICY_AUTOSCALE'].fields_by_name['initial_size']._serialized_options = b'\372\3071\003>=1'
  _globals['_SCALEPOLICY_AUTOSCALE'].fields_by_name['custom_rules']._loaded_options = None
  _globals['_SCALEPOLICY_AUTOSCALE'].fields_by_name['custom_rules']._serialized_options = b'\202\3101\003<=3'
  _globals['_SCALEPOLICY_CPUUTILIZATIONRULE'].fields_by_name['utilization_target']._loaded_options = None
  _globals['_SCALEPOLICY_CPUUTILIZATIONRULE'].fields_by_name['utilization_target']._serialized_options = b'\372\3071\00610-100'
  _globals['_SCALEPOLICY_CUSTOMRULE_LABELSENTRY']._loaded_options = None
  _globals['_SCALEPOLICY_CUSTOMRULE_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_SCALEPOLICY_CUSTOMRULE'].fields_by_name['rule_type']._loaded_options = None
  _globals['_SCALEPOLICY_CUSTOMRULE'].fields_by_name['rule_type']._serialized_options = b'\350\3071\001'
  _globals['_SCALEPOLICY_CUSTOMRULE'].fields_by_name['metric_type']._loaded_options = None
  _globals['_SCALEPOLICY_CUSTOMRULE'].fields_by_name['metric_type']._serialized_options = b'\350\3071\001'
  _globals['_SCALEPOLICY_CUSTOMRULE'].fields_by_name['metric_name']._loaded_options = None
  _globals['_SCALEPOLICY_CUSTOMRULE'].fields_by_name['metric_name']._serialized_options = b'\350\3071\001\362\30712[a-zA-Z0-9./@_][ 0-9a-zA-Z./@_,:;()\\[\\]<>-]{0,198}'
  _globals['_SCALEPOLICY_CUSTOMRULE'].fields_by_name['labels']._loaded_options = None
  _globals['_SCALEPOLICY_CUSTOMRULE'].fields_by_name['labels']._serialized_options = b'\362\30712[a-zA-Z0-9./@_][ 0-9a-zA-Z./@_,:;()\\[\\]<>-]{0,198}\262\3101\036\022\034^[a-zA-Z][0-9a-zA-Z_]{0,31}$'
  _globals['_SCALEPOLICY_CUSTOMRULE'].fields_by_name['target']._loaded_options = None
  _globals['_SCALEPOLICY_CUSTOMRULE'].fields_by_name['target']._serialized_options = b'\372\3071\002>0'
  _globals['_SCALEPOLICY_CUSTOMRULE'].fields_by_name['folder_id']._loaded_options = None
  _globals['_SCALEPOLICY_CUSTOMRULE'].fields_by_name['folder_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_SCALEPOLICY_CUSTOMRULE'].fields_by_name['service']._loaded_options = None
  _globals['_SCALEPOLICY_CUSTOMRULE'].fields_by_name['service']._serialized_options = b'\212\3101\005<=200'
  _globals['_SCALEPOLICY_FIXEDSCALE'].fields_by_name['size']._loaded_options = None
  _globals['_SCALEPOLICY_FIXEDSCALE'].fields_by_name['size']._serialized_options = b'\372\3071\0051-100'
  _globals['_SCALEPOLICY'].oneofs_by_name['scale_type']._loaded_options = None
  _globals['_SCALEPOLICY'].oneofs_by_name['scale_type']._serialized_options = b'\300\3011\001'
  _globals['_DEPLOYPOLICY'].fields_by_name['max_unavailable']._loaded_options = None
  _globals['_DEPLOYPOLICY'].fields_by_name['max_unavailable']._serialized_options = b'\372\3071\0050-100'
  _globals['_DEPLOYPOLICY'].fields_by_name['max_deleting']._loaded_options = None
  _globals['_DEPLOYPOLICY'].fields_by_name['max_deleting']._serialized_options = b'\372\3071\0050-100'
  _globals['_DEPLOYPOLICY'].fields_by_name['max_creating']._loaded_options = None
  _globals['_DEPLOYPOLICY'].fields_by_name['max_creating']._serialized_options = b'\372\3071\0050-100'
  _globals['_DEPLOYPOLICY'].fields_by_name['max_expansion']._loaded_options = None
  _globals['_DEPLOYPOLICY'].fields_by_name['max_expansion']._serialized_options = b'\372\3071\0050-100'
  _globals['_DEPLOYPOLICY'].fields_by_name['startup_duration']._loaded_options = None
  _globals['_DEPLOYPOLICY'].fields_by_name['startup_duration']._serialized_options = b'\372\3071\0050m-1h'
  _globals['_ALLOCATIONPOLICY_ZONE'].fields_by_name['zone_id']._loaded_options = None
  _globals['_ALLOCATIONPOLICY_ZONE'].fields_by_name['zone_id']._serialized_options = b'\350\3071\001'
  _globals['_ALLOCATIONPOLICY_ZONE'].fields_by_name['instance_tags_pool']._loaded_options = None
  _globals['_ALLOCATIONPOLICY_ZONE'].fields_by_name['instance_tags_pool']._serialized_options = b'\212\3101\0043-50\220\3101\001'
  _globals['_ALLOCATIONPOLICY'].fields_by_name['zones']._loaded_options = None
  _globals['_ALLOCATIONPOLICY'].fields_by_name['zones']._serialized_options = b'\202\3101\003>=1'
  _globals['_INSTANCETEMPLATE_LABELSENTRY']._loaded_options = None
  _globals['_INSTANCETEMPLATE_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_INSTANCETEMPLATE_METADATAENTRY']._loaded_options = None
  _globals['_INSTANCETEMPLATE_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_INSTANCETEMPLATE'].fields_by_name['description']._loaded_options = None
  _globals['_INSTANCETEMPLATE'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_INSTANCETEMPLATE'].fields_by_name['labels']._loaded_options = None
  _globals['_INSTANCETEMPLATE'].fields_by_name['labels']._serialized_options = b'\202\3101\004<=64\212\3101\005<=128\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _globals['_INSTANCETEMPLATE'].fields_by_name['platform_id']._loaded_options = None
  _globals['_INSTANCETEMPLATE'].fields_by_name['platform_id']._serialized_options = b'\350\3071\001'
  _globals['_INSTANCETEMPLATE'].fields_by_name['resources_spec']._loaded_options = None
  _globals['_INSTANCETEMPLATE'].fields_by_name['resources_spec']._serialized_options = b'\350\3071\001'
  _globals['_INSTANCETEMPLATE'].fields_by_name['metadata']._loaded_options = None
  _globals['_INSTANCETEMPLATE'].fields_by_name['metadata']._serialized_options = b'\202\3101\005<=128\212\3101\010<=262144\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_INSTANCETEMPLATE'].fields_by_name['boot_disk_spec']._loaded_options = None
  _globals['_INSTANCETEMPLATE'].fields_by_name['boot_disk_spec']._serialized_options = b'\350\3071\001'
  _globals['_INSTANCETEMPLATE'].fields_by_name['secondary_disk_specs']._loaded_options = None
  _globals['_INSTANCETEMPLATE'].fields_by_name['secondary_disk_specs']._serialized_options = b'\202\3101\003<=3'
  _globals['_INSTANCETEMPLATE'].fields_by_name['network_interface_specs']._loaded_options = None
  _globals['_INSTANCETEMPLATE'].fields_by_name['network_interface_specs']._serialized_options = b'\350\3071\001'
  _globals['_INSTANCETEMPLATE'].fields_by_name['name']._loaded_options = None
  _globals['_INSTANCETEMPLATE'].fields_by_name['name']._serialized_options = b'\212\3101\005<=128'
  _globals['_INSTANCETEMPLATE'].fields_by_name['hostname']._loaded_options = None
  _globals['_INSTANCETEMPLATE'].fields_by_name['hostname']._serialized_options = b'\212\3101\005<=128'
  _globals['_ATTACHEDFILESYSTEMSPEC'].fields_by_name['device_name']._loaded_options = None
  _globals['_ATTACHEDFILESYSTEMSPEC'].fields_by_name['device_name']._serialized_options = b'\362\3071\026|[a-z][-_0-9a-z]{0,19}'
  _globals['_ATTACHEDFILESYSTEMSPEC'].fields_by_name['filesystem_id']._loaded_options = None
  _globals['_ATTACHEDFILESYSTEMSPEC'].fields_by_name['filesystem_id']._serialized_options = b'\362\3071\021[-a-zA-Z0-9._{}]*\212\3101\005<=128'
  _globals['_RESOURCESSPEC'].fields_by_name['memory']._loaded_options = None
  _globals['_RESOURCESSPEC'].fields_by_name['memory']._serialized_options = b'\372\3071\016<=824633720832'
  _globals['_RESOURCESSPEC'].fields_by_name['cores']._loaded_options = None
  _globals['_RESOURCESSPEC'].fields_by_name['cores']._serialized_options = b'\372\3071R2,4,6,8,10,12,14,16,18,20,22,24,26,28,30,32,34,36,40,44,48,52,56,60,64,68,72,76,80'
  _globals['_RESOURCESSPEC'].fields_by_name['core_fraction']._loaded_options = None
  _globals['_RESOURCESSPEC'].fields_by_name['core_fraction']._serialized_options = b'\372\3071\r0,5,20,50,100'
  _globals['_RESOURCESSPEC'].fields_by_name['gpus']._loaded_options = None
  _globals['_RESOURCESSPEC'].fields_by_name['gpus']._serialized_options = b'\372\3071\0070,1,2,4'
  _globals['_ATTACHEDDISKSPEC_DISKSPEC'].fields_by_name['description']._loaded_options = None
  _globals['_ATTACHEDDISKSPEC_DISKSPEC'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_ATTACHEDDISKSPEC_DISKSPEC'].fields_by_name['type_id']._loaded_options = None
  _globals['_ATTACHEDDISKSPEC_DISKSPEC'].fields_by_name['type_id']._serialized_options = b'\350\3071\001'
  _globals['_ATTACHEDDISKSPEC_DISKSPEC'].fields_by_name['size']._loaded_options = None
  _globals['_ATTACHEDDISKSPEC_DISKSPEC'].fields_by_name['size']._serialized_options = b'\372\3071\0264194304-28587302322176'
  _globals['_ATTACHEDDISKSPEC_DISKSPEC'].fields_by_name['image_id']._loaded_options = None
  _globals['_ATTACHEDDISKSPEC_DISKSPEC'].fields_by_name['image_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_ATTACHEDDISKSPEC_DISKSPEC'].fields_by_name['snapshot_id']._loaded_options = None
  _globals['_ATTACHEDDISKSPEC_DISKSPEC'].fields_by_name['snapshot_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_ATTACHEDDISKSPEC'].fields_by_name['mode']._loaded_options = None
  _globals['_ATTACHEDDISKSPEC'].fields_by_name['mode']._serialized_options = b'\350\3071\001'
  _globals['_ATTACHEDDISKSPEC'].fields_by_name['device_name']._loaded_options = None
  _globals['_ATTACHEDDISKSPEC'].fields_by_name['device_name']._serialized_options = b'\362\3071\026|[a-z][-_0-9a-z]{0,19}'
  _globals['_ATTACHEDDISKSPEC'].fields_by_name['disk_spec']._loaded_options = None
  _globals['_ATTACHEDDISKSPEC'].fields_by_name['disk_spec']._serialized_options = b'\350\3071\001'
  _globals['_ATTACHEDDISKSPEC'].fields_by_name['disk_id']._loaded_options = None
  _globals['_ATTACHEDDISKSPEC'].fields_by_name['disk_id']._serialized_options = b'\362\3071\021[-a-zA-Z0-9._{}]*\212\3101\005<=128'
  _globals['_ATTACHEDDISKSPEC'].fields_by_name['name']._loaded_options = None
  _globals['_ATTACHEDDISKSPEC'].fields_by_name['name']._serialized_options = b'\212\3101\005<=128'
  _globals['_DNSRECORDSPEC'].fields_by_name['fqdn']._loaded_options = None
  _globals['_DNSRECORDSPEC'].fields_by_name['fqdn']._serialized_options = b'\350\3071\001'
  _globals['_DNSRECORDSPEC'].fields_by_name['ttl']._loaded_options = None
  _globals['_DNSRECORDSPEC'].fields_by_name['ttl']._serialized_options = b'\372\3071\0070-86400'
  _globals['_LOADBALANCERSPEC'].fields_by_name['max_opening_traffic_duration']._loaded_options = None
  _globals['_LOADBALANCERSPEC'].fields_by_name['max_opening_traffic_duration']._serialized_options = b'\372\3071\004>=1s'
  _globals['_TARGETGROUPSPEC_LABELSENTRY']._loaded_options = None
  _globals['_TARGETGROUPSPEC_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_TARGETGROUPSPEC'].fields_by_name['name']._loaded_options = None
  _globals['_TARGETGROUPSPEC'].fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _globals['_TARGETGROUPSPEC'].fields_by_name['description']._loaded_options = None
  _globals['_TARGETGROUPSPEC'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_TARGETGROUPSPEC'].fields_by_name['labels']._loaded_options = None
  _globals['_TARGETGROUPSPEC'].fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _globals['_APPLICATIONLOADBALANCERSPEC'].fields_by_name['target_group_spec']._loaded_options = None
  _globals['_APPLICATIONLOADBALANCERSPEC'].fields_by_name['target_group_spec']._serialized_options = b'\350\3071\001'
  _globals['_APPLICATIONLOADBALANCERSPEC'].fields_by_name['max_opening_traffic_duration']._loaded_options = None
  _globals['_APPLICATIONLOADBALANCERSPEC'].fields_by_name['max_opening_traffic_duration']._serialized_options = b'\372\3071\004>=1s'
  _globals['_APPLICATIONTARGETGROUPSPEC_LABELSENTRY']._loaded_options = None
  _globals['_APPLICATIONTARGETGROUPSPEC_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_HEALTHCHECKSSPEC'].fields_by_name['health_check_specs']._loaded_options = None
  _globals['_HEALTHCHECKSSPEC'].fields_by_name['health_check_specs']._serialized_options = b'\202\3101\003>=1'
  _globals['_HEALTHCHECKSSPEC'].fields_by_name['max_checking_health_duration']._loaded_options = None
  _globals['_HEALTHCHECKSSPEC'].fields_by_name['max_checking_health_duration']._serialized_options = b'\372\3071\004>=1s'
  _globals['_HEALTHCHECKSPEC_TCPOPTIONS'].fields_by_name['port']._loaded_options = None
  _globals['_HEALTHCHECKSPEC_TCPOPTIONS'].fields_by_name['port']._serialized_options = b'\372\3071\0071-65535'
  _globals['_HEALTHCHECKSPEC_HTTPOPTIONS'].fields_by_name['port']._loaded_options = None
  _globals['_HEALTHCHECKSPEC_HTTPOPTIONS'].fields_by_name['port']._serialized_options = b'\372\3071\0071-65535'
  _globals['_HEALTHCHECKSPEC'].oneofs_by_name['health_check_options']._loaded_options = None
  _globals['_HEALTHCHECKSPEC'].oneofs_by_name['health_check_options']._serialized_options = b'\300\3011\001'
  _globals['_HEALTHCHECKSPEC'].fields_by_name['interval']._loaded_options = None
  _globals['_HEALTHCHECKSPEC'].fields_by_name['interval']._serialized_options = b'\372\3071\0071s-300s'
  _globals['_HEALTHCHECKSPEC'].fields_by_name['timeout']._loaded_options = None
  _globals['_HEALTHCHECKSPEC'].fields_by_name['timeout']._serialized_options = b'\372\3071\0061s-60s'
  _globals['_HEALTHCHECKSPEC'].fields_by_name['unhealthy_threshold']._loaded_options = None
  _globals['_HEALTHCHECKSPEC'].fields_by_name['unhealthy_threshold']._serialized_options = b'\372\3071\0240,2,3,4,5,6,7,8,9,10'
  _globals['_HEALTHCHECKSPEC'].fields_by_name['healthy_threshold']._loaded_options = None
  _globals['_HEALTHCHECKSPEC'].fields_by_name['healthy_threshold']._serialized_options = b'\372\3071\0240,2,3,4,5,6,7,8,9,10'
  _globals['_DNSRECORD'].fields_by_name['fqdn']._loaded_options = None
  _globals['_DNSRECORD'].fields_by_name['fqdn']._serialized_options = b'\350\3071\001'
  _globals['_DNSRECORD'].fields_by_name['ttl']._loaded_options = None
  _globals['_DNSRECORD'].fields_by_name['ttl']._serialized_options = b'\372\3071\0070-86400'
  _globals['_IPVERSION']._serialized_start=12441
  _globals['_IPVERSION']._serialized_end=12500
  _globals['_METADATAOPTION']._serialized_start=12502
  _globals['_METADATAOPTION']._serialized_end=12578
  _globals['_INSTANCEGROUP']._serialized_start=198
  _globals['_INSTANCEGROUP']._serialized_end=1752
  _globals['_INSTANCEGROUP_LABELSENTRY']._serialized_start=1588
  _globals['_INSTANCEGROUP_LABELSENTRY']._serialized_end=1633
  _globals['_INSTANCEGROUP_STATUS']._serialized_start=1635
  _globals['_INSTANCEGROUP_STATUS']._serialized_end=1746
  _globals['_APPLICATIONLOADBALANCERSTATE']._serialized_start=1754
  _globals['_APPLICATIONLOADBALANCERSTATE']._serialized_end=1833
  _globals['_VARIABLE']._serialized_start=1835
  _globals['_VARIABLE']._serialized_end=1914
  _globals['_LOADBALANCERSTATE']._serialized_start=1916
  _globals['_LOADBALANCERSTATE']._serialized_end=1984
  _globals['_MANAGEDINSTANCESSTATE']._serialized_start=1987
  _globals['_MANAGEDINSTANCESSTATE']._serialized_end=2312
  _globals['_MANAGEDINSTANCESSTATE_STATUSES']._serialized_start=2122
  _globals['_MANAGEDINSTANCESSTATE_STATUSES']._serialized_end=2306
  _globals['_SCALEPOLICY']._serialized_start=2315
  _globals['_SCALEPOLICY']._serialized_end=4129
  _globals['_SCALEPOLICY_AUTOSCALE']._serialized_start=2588
  _globals['_SCALEPOLICY_AUTOSCALE']._serialized_end=3267
  _globals['_SCALEPOLICY_AUTOSCALE_AUTOSCALETYPE']._serialized_start=3194
  _globals['_SCALEPOLICY_AUTOSCALE_AUTOSCALETYPE']._serialized_end=3267
  _globals['_SCALEPOLICY_CPUUTILIZATIONRULE']._serialized_start=3269
  _globals['_SCALEPOLICY_CPUUTILIZATIONRULE']._serialized_end=3329
  _globals['_SCALEPOLICY_CUSTOMRULE']._serialized_start=3332
  _globals['_SCALEPOLICY_CUSTOMRULE']._serialized_end=4070
  _globals['_SCALEPOLICY_CUSTOMRULE_LABELSENTRY']._serialized_start=1588
  _globals['_SCALEPOLICY_CUSTOMRULE_LABELSENTRY']._serialized_end=1633
  _globals['_SCALEPOLICY_CUSTOMRULE_RULETYPE']._serialized_start=3935
  _globals['_SCALEPOLICY_CUSTOMRULE_RULETYPE']._serialized_end=4003
  _globals['_SCALEPOLICY_CUSTOMRULE_METRICTYPE']._serialized_start=4005
  _globals['_SCALEPOLICY_CUSTOMRULE_METRICTYPE']._serialized_end=4070
  _globals['_SCALEPOLICY_FIXEDSCALE']._serialized_start=4072
  _globals['_SCALEPOLICY_FIXEDSCALE']._serialized_end=4109
  _globals['_DEPLOYPOLICY']._serialized_start=4132
  _globals['_DEPLOYPOLICY']._serialized_end=4694
  _globals['_DEPLOYPOLICY_STRATEGY']._serialized_start=4519
  _globals['_DEPLOYPOLICY_STRATEGY']._serialized_end=4589
  _globals['_DEPLOYPOLICY_MINIMALACTION']._serialized_start=4591
  _globals['_DEPLOYPOLICY_MINIMALACTION']._serialized_end=4682
  _globals['_ALLOCATIONPOLICY']._serialized_start=4697
  _globals['_ALLOCATIONPOLICY']._serialized_end=4874
  _globals['_ALLOCATIONPOLICY_ZONE']._serialized_start=4803
  _globals['_ALLOCATIONPOLICY_ZONE']._serialized_end=4874
  _globals['_INSTANCETEMPLATE']._serialized_start=4877
  _globals['_INSTANCETEMPLATE']._serialized_end=6196
  _globals['_INSTANCETEMPLATE_LABELSENTRY']._serialized_start=1588
  _globals['_INSTANCETEMPLATE_LABELSENTRY']._serialized_end=1633
  _globals['_INSTANCETEMPLATE_METADATAENTRY']._serialized_start=6149
  _globals['_INSTANCETEMPLATE_METADATAENTRY']._serialized_end=6196
  _globals['_ATTACHEDFILESYSTEMSPEC']._serialized_start=6199
  _globals['_ATTACHEDFILESYSTEMSPEC']._serialized_end=6470
  _globals['_ATTACHEDFILESYSTEMSPEC_MODE']._serialized_start=6411
  _globals['_ATTACHEDFILESYSTEMSPEC_MODE']._serialized_end=6470
  _globals['_PLACEMENTPOLICY']._serialized_start=6473
  _globals['_PLACEMENTPOLICY']._serialized_end=6822
  _globals['_PLACEMENTPOLICY_HOSTAFFINITYRULE']._serialized_start=6623
  _globals['_PLACEMENTPOLICY_HOSTAFFINITYRULE']._serialized_end=6822
  _globals['_PLACEMENTPOLICY_HOSTAFFINITYRULE_OPERATOR']._serialized_start=6766
  _globals['_PLACEMENTPOLICY_HOSTAFFINITYRULE_OPERATOR']._serialized_end=6822
  _globals['_RESOURCESSPEC']._serialized_start=6825
  _globals['_RESOURCESSPEC']._serialized_end=7048
  _globals['_ATTACHEDDISKSPEC']._serialized_start=7051
  _globals['_ATTACHEDDISKSPEC']._serialized_end=7661
  _globals['_ATTACHEDDISKSPEC_DISKSPEC']._serialized_start=7368
  _globals['_ATTACHEDDISKSPEC_DISKSPEC']._serialized_end=7594
  _globals['_ATTACHEDDISKSPEC_MODE']._serialized_start=6411
  _globals['_ATTACHEDDISKSPEC_MODE']._serialized_end=6470
  _globals['_NETWORKINTERFACESPEC']._serialized_start=7664
  _globals['_NETWORKINTERFACESPEC']._serialized_end=7938
  _globals['_PRIMARYADDRESSSPEC']._serialized_start=7941
  _globals['_PRIMARYADDRESSSPEC']._serialized_end=8143
  _globals['_ONETOONENATSPEC']._serialized_start=8146
  _globals['_ONETOONENATSPEC']._serialized_end=8330
  _globals['_DNSRECORDSPEC']._serialized_start=8332
  _globals['_DNSRECORDSPEC']._serialized_end=8427
  _globals['_SCHEDULINGPOLICY']._serialized_start=8429
  _globals['_SCHEDULINGPOLICY']._serialized_end=8468
  _globals['_NETWORKSETTINGS']._serialized_start=8471
  _globals['_NETWORKSETTINGS']._serialized_end=8659
  _globals['_NETWORKSETTINGS_TYPE']._serialized_start=8565
  _globals['_NETWORKSETTINGS_TYPE']._serialized_end=8659
  _globals['_LOADBALANCERSPEC']._serialized_start=8662
  _globals['_LOADBALANCERSPEC']._serialized_end=8874
  _globals['_TARGETGROUPSPEC']._serialized_start=8877
  _globals['_TARGETGROUPSPEC']._serialized_end=9179
  _globals['_TARGETGROUPSPEC_LABELSENTRY']._serialized_start=1588
  _globals['_TARGETGROUPSPEC_LABELSENTRY']._serialized_end=1633
  _globals['_APPLICATIONLOADBALANCERSPEC']._serialized_start=9182
  _globals['_APPLICATIONLOADBALANCERSPEC']._serialized_end=9416
  _globals['_APPLICATIONTARGETGROUPSPEC']._serialized_start=9419
  _globals['_APPLICATIONTARGETGROUPSPEC']._serialized_end=9624
  _globals['_APPLICATIONTARGETGROUPSPEC_LABELSENTRY']._serialized_start=1588
  _globals['_APPLICATIONTARGETGROUPSPEC_LABELSENTRY']._serialized_end=1633
  _globals['_HEALTHCHECKSSPEC']._serialized_start=9627
  _globals['_HEALTHCHECKSSPEC']._serialized_end=9813
  _globals['_HEALTHCHECKSPEC']._serialized_start=9816
  _globals['_HEALTHCHECKSPEC']._serialized_end=10364
  _globals['_HEALTHCHECKSPEC_TCPOPTIONS']._serialized_start=10239
  _globals['_HEALTHCHECKSPEC_TCPOPTIONS']._serialized_end=10278
  _globals['_HEALTHCHECKSPEC_HTTPOPTIONS']._serialized_start=10280
  _globals['_HEALTHCHECKSPEC_HTTPOPTIONS']._serialized_end=10334
  _globals['_MANAGEDINSTANCE']._serialized_start=10367
  _globals['_MANAGEDINSTANCE']._serialized_end=11100
  _globals['_MANAGEDINSTANCE_STATUS']._serialized_start=10730
  _globals['_MANAGEDINSTANCE_STATUS']._serialized_end=11094
  _globals['_NETWORKINTERFACE']._serialized_start=11103
  _globals['_NETWORKINTERFACE']._serialized_end=11342
  _globals['_PRIMARYADDRESS']._serialized_start=11345
  _globals['_PRIMARYADDRESS']._serialized_end=11525
  _globals['_ONETOONENAT']._serialized_start=11528
  _globals['_ONETOONENAT']._serialized_end=11699
  _globals['_DNSRECORD']._serialized_start=11701
  _globals['_DNSRECORD']._serialized_end=11792
  _globals['_LOGRECORD']._serialized_start=11794
  _globals['_LOGRECORD']._serialized_end=11869
  _globals['_AUTOHEALINGPOLICY']._serialized_start=11872
  _globals['_AUTOHEALINGPOLICY']._serialized_end=12091
  _globals['_AUTOHEALINGPOLICY_AUTOHEALINGACTION']._serialized_start=11998
  _globals['_AUTOHEALINGPOLICY_AUTOHEALINGACTION']._serialized_end=12091
  _globals['_METADATAOPTIONS']._serialized_start=12094
  _globals['_METADATAOPTIONS']._serialized_end=12439
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.trino.v1.catalog_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetCatalogRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    CATALOG_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Trino Cluster resource which contains the requested catalog."""
    catalog_id: builtins.str
    """ID of the Trino Catalog resource."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        catalog_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["catalog_id", b"catalog_id", "cluster_id", b"cluster_id"]) -> None: ...

global___GetCatalogRequest = GetCatalogRequest

@typing.final
class ListCatalogsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster to list Trino Catalogs in."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListCatalogsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the [ListCatalogsResponse.next_page_token]
    returned by the previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression must specify:
    1. The field name. Currently you can only use filtering with the [Catalog.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 1-63 characters long and match the regular expression `[a-zA-Z0-9_-]+`.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListCatalogsRequest = ListCatalogsRequest

@typing.final
class ListCatalogsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CATALOGS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListCatalogsRequest.page_size], use the [next_page_token] as the value
    for the [ListCatalogsRequest.page_token] parameter in the next list request. Each subsequent
    list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def catalogs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.trino.v1.catalog_pb2.Catalog]:
        """List of Trino Catalog resources."""

    def __init__(
        self,
        *,
        catalogs: collections.abc.Iterable[yandex.cloud.trino.v1.catalog_pb2.Catalog] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["catalogs", b"catalogs", "next_page_token", b"next_page_token"]) -> None: ...

global___ListCatalogsResponse = ListCatalogsResponse

@typing.final
class CreateCatalogRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    CATALOG_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Trino Cluster where the catalog should be created."""
    @property
    def catalog(self) -> yandex.cloud.trino.v1.catalog_pb2.CatalogSpec:
        """Specification of the catalog to be created."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        catalog: yandex.cloud.trino.v1.catalog_pb2.CatalogSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["catalog", b"catalog"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["catalog", b"catalog", "cluster_id", b"cluster_id"]) -> None: ...

global___CreateCatalogRequest = CreateCatalogRequest

@typing.final
class CreateCatalogMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    CATALOG_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Trino cluster where a catalog is being created."""
    catalog_id: builtins.str
    """ID of the catalog that is being created."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        catalog_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["catalog_id", b"catalog_id", "cluster_id", b"cluster_id"]) -> None: ...

global___CreateCatalogMetadata = CreateCatalogMetadata

@typing.final
class UpdateCatalogRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    CATALOG_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    CATALOG_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Trino Cluster that contains the catalog to update."""
    catalog_id: builtins.str
    """ID of the catalog to update."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the catalog should be updated."""

    @property
    def catalog(self) -> yandex.cloud.trino.v1.catalog_pb2.CatalogUpdateSpec:
        """New values for the specified fields."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        catalog_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        catalog: yandex.cloud.trino.v1.catalog_pb2.CatalogUpdateSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["catalog", b"catalog", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["catalog", b"catalog", "catalog_id", b"catalog_id", "cluster_id", b"cluster_id", "update_mask", b"update_mask"]) -> None: ...

global___UpdateCatalogRequest = UpdateCatalogRequest

@typing.final
class UpdateCatalogMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    CATALOG_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Trino cluster where a catalog is being updated."""
    catalog_id: builtins.str
    """ID of the catalog that is being updated."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        catalog_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["catalog_id", b"catalog_id", "cluster_id", b"cluster_id"]) -> None: ...

global___UpdateCatalogMetadata = UpdateCatalogMetadata

@typing.final
class DeleteCatalogRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    CATALOG_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Trino Cluster resource which contains the requested catalog."""
    catalog_id: builtins.str
    """ID of the Trino Catalog resource."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        catalog_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["catalog_id", b"catalog_id", "cluster_id", b"cluster_id"]) -> None: ...

global___DeleteCatalogRequest = DeleteCatalogRequest

@typing.final
class DeleteCatalogMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    CATALOG_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Trino cluster where a catalog is being deleted."""
    catalog_id: builtins.str
    """ID of the catalog that is being deleted."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        catalog_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["catalog_id", b"catalog_id", "cluster_id", b"cluster_id"]) -> None: ...

global___DeleteCatalogMetadata = DeleteCatalogMetadata



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/searchapi/v2/search_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/searchapi/v2/search_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.searchapi.v2 import search_query_pb2 as yandex_dot_cloud_dot_searchapi_dot_v2_dot_search__query__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.yandex/cloud/searchapi/v2/search_service.proto\x12\x19yandex.cloud.searchapi.v2\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a,yandex/cloud/searchapi/v2/search_query.proto\x1a\x1cgoogle/api/annotations.proto\"\xba\x02\n\x08SortSpec\x12?\n\tsort_mode\x18\x01 \x01(\x0e\x32,.yandex.cloud.searchapi.v2.SortSpec.SortMode\x12\x41\n\nsort_order\x18\x02 \x01(\x0e\x32-.yandex.cloud.searchapi.v2.SortSpec.SortOrder\"P\n\tSortOrder\x12\x1a\n\x16SORT_ORDER_UNSPECIFIED\x10\x00\x12\x12\n\x0eSORT_ORDER_ASC\x10\x01\x12\x13\n\x0fSORT_ORDER_DESC\x10\x02\"X\n\x08SortMode\x12\x19\n\x15SORT_MODE_UNSPECIFIED\x10\x00\x12\x1a\n\x16SORT_MODE_BY_RELEVANCE\x10\x01\x12\x15\n\x11SORT_MODE_BY_TIME\x10\x02\"\xe5\x01\n\tGroupSpec\x12\x42\n\ngroup_mode\x18\x01 \x01(\x0e\x32..yandex.cloud.searchapi.v2.GroupSpec.GroupMode\x12!\n\x0egroups_on_page\x18\x02 \x01(\x03\x42\t\xfa\xc7\x31\x05\x31-100\x12\x1e\n\rdocs_in_group\x18\x03 \x01(\x03\x42\x07\xfa\xc7\x31\x03\x31-3\"Q\n\tGroupMode\x12\x1a\n\x16GROUP_MODE_UNSPECIFIED\x10\x00\x12\x13\n\x0fGROUP_MODE_FLAT\x10\x01\x12\x13\n\x0fGROUP_MODE_DEEP\x10\x02\"\xf9\x05\n\x10WebSearchRequest\x12;\n\x05query\x18\x01 \x01(\x0b\x32&.yandex.cloud.searchapi.v2.SearchQueryB\x04\xe8\xc7\x31\x01\x12\x36\n\tsort_spec\x18\x02 \x01(\x0b\x32#.yandex.cloud.searchapi.v2.SortSpec\x12\x38\n\ngroup_spec\x18\x03 \x01(\x0b\x32$.yandex.cloud.searchapi.v2.GroupSpec\x12\x1d\n\x0cmax_passages\x18\x04 \x01(\x03\x42\x07\xfa\xc7\x31\x03\x31-5\x12\x19\n\x06region\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x46\n\x04l10n\x18\x06 \x01(\x0e\x32\x38.yandex.cloud.searchapi.v2.WebSearchRequest.Localization\x12\x1b\n\tfolder_id\x18\x07 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12K\n\x0fresponse_format\x18\x08 \x01(\x0e\x32\x32.yandex.cloud.searchapi.v2.WebSearchRequest.Format\x12\x1d\n\nuser_agent\x18\t \x01(\tB\t\x8a\xc8\x31\x05<=300\x12;\n\x08metadata\x18\n \x01(\x0b\x32).yandex.cloud.searchapi.v2.SearchMetadata\"\xaa\x01\n\x0cLocalization\x12\x1c\n\x18LOCALIZATION_UNSPECIFIED\x10\x00\x12\x13\n\x0fLOCALIZATION_RU\x10\x01\x12\x13\n\x0fLOCALIZATION_UK\x10\x02\x12\x13\n\x0fLOCALIZATION_BE\x10\x03\x12\x13\n\x0fLOCALIZATION_KK\x10\x04\x12\x13\n\x0fLOCALIZATION_TR\x10\x05\x12\x13\n\x0fLOCALIZATION_EN\x10\x06\"A\n\x06\x46ormat\x12\x16\n\x12\x46ORMAT_UNSPECIFIED\x10\x00\x12\x0e\n\nFORMAT_XML\x10\x01\x12\x0f\n\x0b\x46ORMAT_HTML\x10\x02\"+\n\x11WebSearchResponse\x12\x16\n\x08raw_data\x18\x01 \x01(\x0c\x42\x04\xe8\xc7\x31\x01\x32\xa9\x01\n\x15WebSearchAsyncService\x12\x8f\x01\n\x06Search\x12+.yandex.cloud.searchapi.v2.WebSearchRequest\x1a!.yandex.cloud.operation.Operation\"5\xb2\xd2*\x13\x12\x11WebSearchResponse\x82\xd3\xe4\x93\x02\x18\"\x13/v2/web/searchAsync:\x01*2\x92\x01\n\x10WebSearchService\x12~\n\x06Search\x12+.yandex.cloud.searchapi.v2.WebSearchRequest\x1a,.yandex.cloud.searchapi.v2.WebSearchResponse\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/v2/web/search:\x01*Be\n\x1ayandex.cloud.api.search.v2ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/searchapi/v2;searchapib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.searchapi.v2.search_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032yandex.cloud.api.search.v2ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/searchapi/v2;searchapi'
  _globals['_GROUPSPEC'].fields_by_name['groups_on_page']._loaded_options = None
  _globals['_GROUPSPEC'].fields_by_name['groups_on_page']._serialized_options = b'\372\3071\0051-100'
  _globals['_GROUPSPEC'].fields_by_name['docs_in_group']._loaded_options = None
  _globals['_GROUPSPEC'].fields_by_name['docs_in_group']._serialized_options = b'\372\3071\0031-3'
  _globals['_WEBSEARCHREQUEST'].fields_by_name['query']._loaded_options = None
  _globals['_WEBSEARCHREQUEST'].fields_by_name['query']._serialized_options = b'\350\3071\001'
  _globals['_WEBSEARCHREQUEST'].fields_by_name['max_passages']._loaded_options = None
  _globals['_WEBSEARCHREQUEST'].fields_by_name['max_passages']._serialized_options = b'\372\3071\0031-5'
  _globals['_WEBSEARCHREQUEST'].fields_by_name['region']._loaded_options = None
  _globals['_WEBSEARCHREQUEST'].fields_by_name['region']._serialized_options = b'\212\3101\005<=100'
  _globals['_WEBSEARCHREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_WEBSEARCHREQUEST'].fields_by_name['folder_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_WEBSEARCHREQUEST'].fields_by_name['user_agent']._loaded_options = None
  _globals['_WEBSEARCHREQUEST'].fields_by_name['user_agent']._serialized_options = b'\212\3101\005<=300'
  _globals['_WEBSEARCHRESPONSE'].fields_by_name['raw_data']._loaded_options = None
  _globals['_WEBSEARCHRESPONSE'].fields_by_name['raw_data']._serialized_options = b'\350\3071\001'
  _globals['_WEBSEARCHASYNCSERVICE'].methods_by_name['Search']._loaded_options = None
  _globals['_WEBSEARCHASYNCSERVICE'].methods_by_name['Search']._serialized_options = b'\262\322*\023\022\021WebSearchResponse\202\323\344\223\002\030\"\023/v2/web/searchAsync:\001*'
  _globals['_WEBSEARCHSERVICE'].methods_by_name['Search']._loaded_options = None
  _globals['_WEBSEARCHSERVICE'].methods_by_name['Search']._serialized_options = b'\202\323\344\223\002\023\"\016/v2/web/search:\001*'
  _globals['_SORTSPEC']._serialized_start=259
  _globals['_SORTSPEC']._serialized_end=573
  _globals['_SORTSPEC_SORTORDER']._serialized_start=403
  _globals['_SORTSPEC_SORTORDER']._serialized_end=483
  _globals['_SORTSPEC_SORTMODE']._serialized_start=485
  _globals['_SORTSPEC_SORTMODE']._serialized_end=573
  _globals['_GROUPSPEC']._serialized_start=576
  _globals['_GROUPSPEC']._serialized_end=805
  _globals['_GROUPSPEC_GROUPMODE']._serialized_start=724
  _globals['_GROUPSPEC_GROUPMODE']._serialized_end=805
  _globals['_WEBSEARCHREQUEST']._serialized_start=808
  _globals['_WEBSEARCHREQUEST']._serialized_end=1569
  _globals['_WEBSEARCHREQUEST_LOCALIZATION']._serialized_start=1332
  _globals['_WEBSEARCHREQUEST_LOCALIZATION']._serialized_end=1502
  _globals['_WEBSEARCHREQUEST_FORMAT']._serialized_start=1504
  _globals['_WEBSEARCHREQUEST_FORMAT']._serialized_end=1569
  _globals['_WEBSEARCHRESPONSE']._serialized_start=1571
  _globals['_WEBSEARCHRESPONSE']._serialized_end=1614
  _globals['_WEBSEARCHASYNCSERVICE']._serialized_start=1617
  _globals['_WEBSEARCHASYNCSERVICE']._serialized_end=1786
  _globals['_WEBSEARCHSERVICE']._serialized_start=1789
  _globals['_WEBSEARCHSERVICE']._serialized_end=1935
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.logging.v1.log_entry_pb2
import yandex.cloud.metastore.v1.maintenance_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Cluster(google.protobuf.message.Message):
    """Metastore Cluster."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Health:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _HealthEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Cluster._Health.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        HEALTH_UNKNOWN: Cluster._Health.ValueType  # 0
        """Cluster is in unknown state (we have no data)."""
        ALIVE: Cluster._Health.ValueType  # 1
        """Cluster is alive and operates properly."""
        DEAD: Cluster._Health.ValueType  # 2
        """Cluster is inoperable (it cannot perform any of its essential functions)."""
        DEGRADED: Cluster._Health.ValueType  # 3
        """Cluster is partially alive (it can perform some of its essential functions)."""

    class Health(_Health, metaclass=_HealthEnumTypeWrapper): ...
    HEALTH_UNKNOWN: Cluster.Health.ValueType  # 0
    """Cluster is in unknown state (we have no data)."""
    ALIVE: Cluster.Health.ValueType  # 1
    """Cluster is alive and operates properly."""
    DEAD: Cluster.Health.ValueType  # 2
    """Cluster is inoperable (it cannot perform any of its essential functions)."""
    DEGRADED: Cluster.Health.ValueType  # 3
    """Cluster is partially alive (it can perform some of its essential functions)."""

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Cluster._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNKNOWN: Cluster._Status.ValueType  # 0
        """Cluster state is unknown."""
        CREATING: Cluster._Status.ValueType  # 1
        """Cluster is being created."""
        RUNNING: Cluster._Status.ValueType  # 2
        """Cluster is running normally."""
        ERROR: Cluster._Status.ValueType  # 3
        """Cluster encountered a problem and cannot operate."""
        UPDATING: Cluster._Status.ValueType  # 4
        """Cluster is being updated."""
        STOPPING: Cluster._Status.ValueType  # 5
        """Cluster is stopping."""
        STOPPED: Cluster._Status.ValueType  # 6
        """Cluster stopped."""
        STARTING: Cluster._Status.ValueType  # 7
        """Cluster is starting."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNKNOWN: Cluster.Status.ValueType  # 0
    """Cluster state is unknown."""
    CREATING: Cluster.Status.ValueType  # 1
    """Cluster is being created."""
    RUNNING: Cluster.Status.ValueType  # 2
    """Cluster is running normally."""
    ERROR: Cluster.Status.ValueType  # 3
    """Cluster encountered a problem and cannot operate."""
    UPDATING: Cluster.Status.ValueType  # 4
    """Cluster is being updated."""
    STOPPING: Cluster.Status.ValueType  # 5
    """Cluster is stopping."""
    STOPPED: Cluster.Status.ValueType  # 6
    """Cluster stopped."""
    STARTING: Cluster.Status.ValueType  # 7
    """Cluster is starting."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    MONITORING_FIELD_NUMBER: builtins.int
    HEALTH_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    ENDPOINT_IP_FIELD_NUMBER: builtins.int
    CLUSTER_CONFIG_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    LOGGING_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    PLANNED_OPERATION_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Unique ID of the Metastore Cluster.
    This ID is assigned by Cloud in the process of creating a Trino cluster.
    """
    folder_id: builtins.str
    """ID of the folder that the Metastore Cluster belongs to."""
    name: builtins.str
    """Name of the Metastore Cluster.
    The name is unique within the folder.
    """
    description: builtins.str
    """Description of the Metastore Cluster."""
    health: global___Cluster.Health.ValueType
    """Aggregated cluster health."""
    status: global___Cluster.Status.ValueType
    """Cluster status."""
    deletion_protection: builtins.bool
    """Deletion Protection prevents deletion of the cluster."""
    version: builtins.str
    """Metastore server version."""
    network_id: builtins.str
    """Metastore network ID."""
    endpoint_ip: builtins.str
    """IP address of the Metastore server load balancer."""
    service_account_id: builtins.str
    """Service account used to access Cloud resources."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The time the Metastore Cluster was created at."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels for the Metastore Cluster as `` key:value `` pairs."""

    @property
    def monitoring(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Monitoring]:
        """Monitoring systems relevant to the Metastore Cluster."""

    @property
    def cluster_config(self) -> global___ClusterConfig:
        """Configuration of the Metastore Cluster."""

    @property
    def logging(self) -> global___LoggingConfig:
        """Cloud logging configuration."""

    @property
    def network(self) -> global___NetworkConfig:
        """Network-related configuration options."""

    @property
    def maintenance_window(self) -> yandex.cloud.metastore.v1.maintenance_pb2.MaintenanceWindow:
        """Maintenance window."""

    @property
    def planned_operation(self) -> yandex.cloud.metastore.v1.maintenance_pb2.MaintenanceOperation:
        """Maintenance operation scheduled for the nearest maintenance window."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        monitoring: collections.abc.Iterable[global___Monitoring] | None = ...,
        health: global___Cluster.Health.ValueType = ...,
        status: global___Cluster.Status.ValueType = ...,
        deletion_protection: builtins.bool = ...,
        version: builtins.str = ...,
        network_id: builtins.str = ...,
        endpoint_ip: builtins.str = ...,
        cluster_config: global___ClusterConfig | None = ...,
        service_account_id: builtins.str = ...,
        logging: global___LoggingConfig | None = ...,
        network: global___NetworkConfig | None = ...,
        maintenance_window: yandex.cloud.metastore.v1.maintenance_pb2.MaintenanceWindow | None = ...,
        planned_operation: yandex.cloud.metastore.v1.maintenance_pb2.MaintenanceOperation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cluster_config", b"cluster_config", "created_at", b"created_at", "logging", b"logging", "maintenance_window", b"maintenance_window", "network", b"network", "planned_operation", b"planned_operation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_config", b"cluster_config", "created_at", b"created_at", "deletion_protection", b"deletion_protection", "description", b"description", "endpoint_ip", b"endpoint_ip", "folder_id", b"folder_id", "health", b"health", "id", b"id", "labels", b"labels", "logging", b"logging", "maintenance_window", b"maintenance_window", "monitoring", b"monitoring", "name", b"name", "network", b"network", "network_id", b"network_id", "planned_operation", b"planned_operation", "service_account_id", b"service_account_id", "status", b"status", "version", b"version"]) -> None: ...

global___Cluster = Cluster

@typing.final
class Monitoring(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the monitoring system."""
    description: builtins.str
    """Description of the monitoring system."""
    link: builtins.str
    """Link to the monitoring system."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "link", b"link", "name", b"name"]) -> None: ...

global___Monitoring = Monitoring

@typing.final
class ClusterConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCES_FIELD_NUMBER: builtins.int
    @property
    def resources(self) -> global___Resources:
        """Configuration for computational resources for Metastore server instances."""

    def __init__(
        self,
        *,
        resources: global___Resources | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resources", b"resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["resources", b"resources"]) -> None: ...

global___ClusterConfig = ClusterConfig

@typing.final
class NetworkConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBNET_IDS_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    @property
    def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IDs of VPC network subnets where instances of the cluster are attached."""

    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """User security groups."""

    def __init__(
        self,
        *,
        subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["security_group_ids", b"security_group_ids", "subnet_ids", b"subnet_ids"]) -> None: ...

global___NetworkConfig = NetworkConfig

@typing.final
class Resources(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_PRESET_ID_FIELD_NUMBER: builtins.int
    resource_preset_id: builtins.str
    """ID of the preset for computational resources allocated to an instance (e.g., CPU, memory, etc.)."""
    def __init__(
        self,
        *,
        resource_preset_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["resource_preset_id", b"resource_preset_id"]) -> None: ...

global___Resources = Resources

@typing.final
class LoggingConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    LOG_GROUP_ID_FIELD_NUMBER: builtins.int
    MIN_LEVEL_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    """Logs generated by the Metastore server are delivered to Cloud Logging."""
    folder_id: builtins.str
    """Logs will be written to the default log group of the specified folder."""
    log_group_id: builtins.str
    """Logs will be written to the log group specified by its ID."""
    min_level: yandex.cloud.logging.v1.log_entry_pb2.LogLevel.Level.ValueType
    """Minimum severity level for log entries.

    See [LogLevel.Level] for details.
    """
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        folder_id: builtins.str = ...,
        log_group_id: builtins.str = ...,
        min_level: yandex.cloud.logging.v1.log_entry_pb2.LogLevel.Level.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["destination", b"destination", "folder_id", b"folder_id", "log_group_id", b"log_group_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["destination", b"destination", "enabled", b"enabled", "folder_id", b"folder_id", "log_group_id", b"log_group_id", "min_level", b"min_level"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["destination", b"destination"]) -> typing.Literal["folder_id", "log_group_id"] | None: ...

global___LoggingConfig = LoggingConfig



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.baremetal.v1alpha.server_pb2
import yandex.cloud.baremetal.v1alpha.server_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ServerServiceStub:
    """A set of methods for managing Server resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.server_service_pb2.GetServerRequest,
        yandex.cloud.baremetal.v1alpha.server_pb2.Server,
    ]
    """Returns the specific Server resource.

    To get the list of available Server resources, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.server_service_pb2.ListServerRequest,
        yandex.cloud.baremetal.v1alpha.server_service_pb2.ListServerResponse,
    ]
    """Retrieves the list of Server resources in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.server_service_pb2.CreateServerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a server in the specified folder."""

    BatchCreate: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.server_service_pb2.BatchCreateServersRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates multiple servers in the specified folder."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.server_service_pb2.UpdateServerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified server."""

    PowerOff: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.server_service_pb2.PowerOffServerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Powers off the specified server."""

    PowerOn: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.server_service_pb2.PowerOnServerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Powers on the specified server."""

    Reboot: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.server_service_pb2.RebootServerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Reboots the specified server."""

    Reinstall: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.server_service_pb2.ReinstallServerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Reinstalls the specified server."""

    StartProlongation: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.server_service_pb2.StartProlongationRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Starts prolongation of the specified server."""

    StopProlongation: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.server_service_pb2.StopProlongationRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Stops prolongation of the specified server."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.server_service_pb2.ListServerOperationsRequest,
        yandex.cloud.baremetal.v1alpha.server_service_pb2.ListServerOperationsResponse,
    ]
    """Lists operations for the specified server."""

class ServerServiceAsyncStub:
    """A set of methods for managing Server resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.server_service_pb2.GetServerRequest,
        yandex.cloud.baremetal.v1alpha.server_pb2.Server,
    ]
    """Returns the specific Server resource.

    To get the list of available Server resources, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.server_service_pb2.ListServerRequest,
        yandex.cloud.baremetal.v1alpha.server_service_pb2.ListServerResponse,
    ]
    """Retrieves the list of Server resources in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.server_service_pb2.CreateServerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a server in the specified folder."""

    BatchCreate: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.server_service_pb2.BatchCreateServersRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates multiple servers in the specified folder."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.server_service_pb2.UpdateServerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified server."""

    PowerOff: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.server_service_pb2.PowerOffServerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Powers off the specified server."""

    PowerOn: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.server_service_pb2.PowerOnServerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Powers on the specified server."""

    Reboot: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.server_service_pb2.RebootServerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Reboots the specified server."""

    Reinstall: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.server_service_pb2.ReinstallServerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Reinstalls the specified server."""

    StartProlongation: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.server_service_pb2.StartProlongationRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Starts prolongation of the specified server."""

    StopProlongation: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.server_service_pb2.StopProlongationRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Stops prolongation of the specified server."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.server_service_pb2.ListServerOperationsRequest,
        yandex.cloud.baremetal.v1alpha.server_service_pb2.ListServerOperationsResponse,
    ]
    """Lists operations for the specified server."""

class ServerServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing Server resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.baremetal.v1alpha.server_service_pb2.GetServerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.baremetal.v1alpha.server_pb2.Server, collections.abc.Awaitable[yandex.cloud.baremetal.v1alpha.server_pb2.Server]]:
        """Returns the specific Server resource.

        To get the list of available Server resources, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.baremetal.v1alpha.server_service_pb2.ListServerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.baremetal.v1alpha.server_service_pb2.ListServerResponse, collections.abc.Awaitable[yandex.cloud.baremetal.v1alpha.server_service_pb2.ListServerResponse]]:
        """Retrieves the list of Server resources in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.baremetal.v1alpha.server_service_pb2.CreateServerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a server in the specified folder."""

    @abc.abstractmethod
    def BatchCreate(
        self,
        request: yandex.cloud.baremetal.v1alpha.server_service_pb2.BatchCreateServersRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates multiple servers in the specified folder."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.baremetal.v1alpha.server_service_pb2.UpdateServerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified server."""

    @abc.abstractmethod
    def PowerOff(
        self,
        request: yandex.cloud.baremetal.v1alpha.server_service_pb2.PowerOffServerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Powers off the specified server."""

    @abc.abstractmethod
    def PowerOn(
        self,
        request: yandex.cloud.baremetal.v1alpha.server_service_pb2.PowerOnServerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Powers on the specified server."""

    @abc.abstractmethod
    def Reboot(
        self,
        request: yandex.cloud.baremetal.v1alpha.server_service_pb2.RebootServerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Reboots the specified server."""

    @abc.abstractmethod
    def Reinstall(
        self,
        request: yandex.cloud.baremetal.v1alpha.server_service_pb2.ReinstallServerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Reinstalls the specified server."""

    @abc.abstractmethod
    def StartProlongation(
        self,
        request: yandex.cloud.baremetal.v1alpha.server_service_pb2.StartProlongationRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Starts prolongation of the specified server."""

    @abc.abstractmethod
    def StopProlongation(
        self,
        request: yandex.cloud.baremetal.v1alpha.server_service_pb2.StopProlongationRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Stops prolongation of the specified server."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.baremetal.v1alpha.server_service_pb2.ListServerOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.baremetal.v1alpha.server_service_pb2.ListServerOperationsResponse, collections.abc.Awaitable[yandex.cloud.baremetal.v1alpha.server_service_pb2.ListServerOperationsResponse]]:
        """Lists operations for the specified server."""

def add_ServerServiceServicer_to_server(servicer: ServerServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/apploadbalancer/v1/package_options.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/apploadbalancer/v1/package_options.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5yandex/cloud/apploadbalancer/v1/package_options.proto\x12\x1fyandex.cloud.apploadbalancer.v1BUZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.apploadbalancer.v1.package_options_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancer'
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/kafka/v1/connector_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/kafka/v1/connector_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.kafka.v1 import connector_pb2 as yandex_dot_cloud_dot_mdb_dot_kafka_dot_v1_dot_connector__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1yandex/cloud/mdb/kafka/v1/connector_service.proto\x12\x19yandex.cloud.mdb.kafka.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a)yandex/cloud/mdb/kafka/v1/connector.proto\"q\n\x13GetConnectorRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x38\n\x0e\x63onnector_name\x18\x02 \x01(\tB \xe8\xc7\x31\x01\xf2\xc7\x31\x0f[-_.a-zA-Z0-9]*\x8a\xc8\x31\x05<=256\"w\n\x15ListConnectorsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"k\n\x16ListConnectorsResponse\x12\x38\n\nconnectors\x18\x01 \x03(\x0b\x32$.yandex.cloud.mdb.kafka.v1.Connector\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x82\x01\n\x16\x43reateConnectorRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x46\n\x0e\x63onnector_spec\x18\x02 \x01(\x0b\x32(.yandex.cloud.mdb.kafka.v1.ConnectorSpecB\x04\xe8\xc7\x31\x01\"g\n\x17\x43reateConnectorMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x38\n\x0e\x63onnector_name\x18\x02 \x01(\tB \xe8\xc7\x31\x01\xf2\xc7\x31\x0f[-_.a-zA-Z0-9]*\x8a\xc8\x31\x05<=256\"\xf3\x01\n\x16UpdateConnectorRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x38\n\x0e\x63onnector_name\x18\x02 \x01(\tB \xe8\xc7\x31\x01\xf2\xc7\x31\x0f[-_.a-zA-Z0-9]*\x8a\xc8\x31\x05<=256\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12L\n\x0e\x63onnector_spec\x18\x04 \x01(\x0b\x32..yandex.cloud.mdb.kafka.v1.UpdateConnectorSpecB\x04\xe8\xc7\x31\x01\"u\n\x17UpdateConnectorMetadata\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x38\n\x0e\x63onnector_name\x18\x02 \x01(\tB \xe8\xc7\x31\x01\xf2\xc7\x31\x0f[-_.a-zA-Z0-9]*\x8a\xc8\x31\x05<=256\"t\n\x16\x44\x65leteConnectorRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x38\n\x0e\x63onnector_name\x18\x02 \x01(\tB \xe8\xc7\x31\x01\xf2\xc7\x31\x0f[-_.a-zA-Z0-9]*\x8a\xc8\x31\x05<=256\"E\n\x17\x44\x65leteConnectorMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x16\n\x0e\x63onnector_name\x18\x02 \x01(\t\"t\n\x16ResumeConnectorRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x38\n\x0e\x63onnector_name\x18\x02 \x01(\tB \xe8\xc7\x31\x01\xf2\xc7\x31\x0f[-_.a-zA-Z0-9]*\x8a\xc8\x31\x05<=256\"g\n\x17ResumeConnectorMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x38\n\x0e\x63onnector_name\x18\x02 \x01(\tB \xe8\xc7\x31\x01\xf2\xc7\x31\x0f[-_.a-zA-Z0-9]*\x8a\xc8\x31\x05<=256\"s\n\x15PauseConnectorRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x38\n\x0e\x63onnector_name\x18\x02 \x01(\tB \xe8\xc7\x31\x01\xf2\xc7\x31\x0f[-_.a-zA-Z0-9]*\x8a\xc8\x31\x05<=256\"f\n\x16PauseConnectorMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x38\n\x0e\x63onnector_name\x18\x02 \x01(\tB \xe8\xc7\x31\x01\xf2\xc7\x31\x0f[-_.a-zA-Z0-9]*\x8a\xc8\x31\x05<=2562\xa6\x0b\n\x10\x43onnectorService\x12\xa8\x01\n\x03Get\x12..yandex.cloud.mdb.kafka.v1.GetConnectorRequest\x1a$.yandex.cloud.mdb.kafka.v1.Connector\"K\x82\xd3\xe4\x93\x02\x45\x12\x43/managed-kafka/v1/clusters/{cluster_id}/connectors/{connector_name}\x12\xa7\x01\n\x04List\x12\x30.yandex.cloud.mdb.kafka.v1.ListConnectorsRequest\x1a\x31.yandex.cloud.mdb.kafka.v1.ListConnectorsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/managed-kafka/v1/clusters/{cluster_id}/connectors\x12\xc5\x01\n\x06\x43reate\x12\x31.yandex.cloud.mdb.kafka.v1.CreateConnectorRequest\x1a!.yandex.cloud.operation.Operation\"e\xb2\xd2*$\n\x17\x43reateConnectorMetadata\x12\tConnector\x82\xd3\xe4\x93\x02\x37\"2/managed-kafka/v1/clusters/{cluster_id}/connectors:\x01*\x12\xd6\x01\n\x06Update\x12\x31.yandex.cloud.mdb.kafka.v1.UpdateConnectorRequest\x1a!.yandex.cloud.operation.Operation\"v\xb2\xd2*$\n\x17UpdateConnectorMetadata\x12\tConnector\x82\xd3\xe4\x93\x02H2C/managed-kafka/v1/clusters/{cluster_id}/connectors/{connector_name}:\x01*\x12\xdf\x01\n\x06\x44\x65lete\x12\x31.yandex.cloud.mdb.kafka.v1.DeleteConnectorRequest\x1a!.yandex.cloud.operation.Operation\"\x7f\xb2\xd2*0\n\x17\x44\x65leteConnectorMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x45*C/managed-kafka/v1/clusters/{cluster_id}/connectors/{connector_name}\x12\xdd\x01\n\x06Resume\x12\x31.yandex.cloud.mdb.kafka.v1.ResumeConnectorRequest\x1a!.yandex.cloud.operation.Operation\"}\xb2\xd2*$\n\x17ResumeConnectorMetadata\x12\tConnector\x82\xd3\xe4\x93\x02O\"J/managed-kafka/v1/clusters/{cluster_id}/connectors/resume/{connector_name}:\x01*\x12\xd9\x01\n\x05Pause\x12\x30.yandex.cloud.mdb.kafka.v1.PauseConnectorRequest\x1a!.yandex.cloud.operation.Operation\"{\xb2\xd2*#\n\x16PauseConnectorMetadata\x12\tConnector\x82\xd3\xe4\x93\x02N\"I/managed-kafka/v1/clusters/{cluster_id}/connectors/pause/{connector_name}:\x01*Bd\n\x1dyandex.cloud.api.mdb.kafka.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/kafka/v1;kafkab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.kafka.v1.connector_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035yandex.cloud.api.mdb.kafka.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/kafka/v1;kafka'
  _globals['_GETCONNECTORREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_GETCONNECTORREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETCONNECTORREQUEST'].fields_by_name['connector_name']._loaded_options = None
  _globals['_GETCONNECTORREQUEST'].fields_by_name['connector_name']._serialized_options = b'\350\3071\001\362\3071\017[-_.a-zA-Z0-9]*\212\3101\005<=256'
  _globals['_LISTCONNECTORSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCONNECTORSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCONNECTORSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCONNECTORSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTCONNECTORSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCONNECTORSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_CREATECONNECTORREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_CREATECONNECTORREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATECONNECTORREQUEST'].fields_by_name['connector_spec']._loaded_options = None
  _globals['_CREATECONNECTORREQUEST'].fields_by_name['connector_spec']._serialized_options = b'\350\3071\001'
  _globals['_CREATECONNECTORMETADATA'].fields_by_name['connector_name']._loaded_options = None
  _globals['_CREATECONNECTORMETADATA'].fields_by_name['connector_name']._serialized_options = b'\350\3071\001\362\3071\017[-_.a-zA-Z0-9]*\212\3101\005<=256'
  _globals['_UPDATECONNECTORREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATECONNECTORREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATECONNECTORREQUEST'].fields_by_name['connector_name']._loaded_options = None
  _globals['_UPDATECONNECTORREQUEST'].fields_by_name['connector_name']._serialized_options = b'\350\3071\001\362\3071\017[-_.a-zA-Z0-9]*\212\3101\005<=256'
  _globals['_UPDATECONNECTORREQUEST'].fields_by_name['connector_spec']._loaded_options = None
  _globals['_UPDATECONNECTORREQUEST'].fields_by_name['connector_spec']._serialized_options = b'\350\3071\001'
  _globals['_UPDATECONNECTORMETADATA'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATECONNECTORMETADATA'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATECONNECTORMETADATA'].fields_by_name['connector_name']._loaded_options = None
  _globals['_UPDATECONNECTORMETADATA'].fields_by_name['connector_name']._serialized_options = b'\350\3071\001\362\3071\017[-_.a-zA-Z0-9]*\212\3101\005<=256'
  _globals['_DELETECONNECTORREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETECONNECTORREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETECONNECTORREQUEST'].fields_by_name['connector_name']._loaded_options = None
  _globals['_DELETECONNECTORREQUEST'].fields_by_name['connector_name']._serialized_options = b'\350\3071\001\362\3071\017[-_.a-zA-Z0-9]*\212\3101\005<=256'
  _globals['_RESUMECONNECTORREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_RESUMECONNECTORREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_RESUMECONNECTORREQUEST'].fields_by_name['connector_name']._loaded_options = None
  _globals['_RESUMECONNECTORREQUEST'].fields_by_name['connector_name']._serialized_options = b'\350\3071\001\362\3071\017[-_.a-zA-Z0-9]*\212\3101\005<=256'
  _globals['_RESUMECONNECTORMETADATA'].fields_by_name['connector_name']._loaded_options = None
  _globals['_RESUMECONNECTORMETADATA'].fields_by_name['connector_name']._serialized_options = b'\350\3071\001\362\3071\017[-_.a-zA-Z0-9]*\212\3101\005<=256'
  _globals['_PAUSECONNECTORREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_PAUSECONNECTORREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_PAUSECONNECTORREQUEST'].fields_by_name['connector_name']._loaded_options = None
  _globals['_PAUSECONNECTORREQUEST'].fields_by_name['connector_name']._serialized_options = b'\350\3071\001\362\3071\017[-_.a-zA-Z0-9]*\212\3101\005<=256'
  _globals['_PAUSECONNECTORMETADATA'].fields_by_name['connector_name']._loaded_options = None
  _globals['_PAUSECONNECTORMETADATA'].fields_by_name['connector_name']._serialized_options = b'\350\3071\001\362\3071\017[-_.a-zA-Z0-9]*\212\3101\005<=256'
  _globals['_CONNECTORSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_CONNECTORSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002E\022C/managed-kafka/v1/clusters/{cluster_id}/connectors/{connector_name}'
  _globals['_CONNECTORSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_CONNECTORSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\0024\0222/managed-kafka/v1/clusters/{cluster_id}/connectors'
  _globals['_CONNECTORSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_CONNECTORSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*$\n\027CreateConnectorMetadata\022\tConnector\202\323\344\223\0027\"2/managed-kafka/v1/clusters/{cluster_id}/connectors:\001*'
  _globals['_CONNECTORSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_CONNECTORSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*$\n\027UpdateConnectorMetadata\022\tConnector\202\323\344\223\002H2C/managed-kafka/v1/clusters/{cluster_id}/connectors/{connector_name}:\001*'
  _globals['_CONNECTORSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_CONNECTORSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*0\n\027DeleteConnectorMetadata\022\025google.protobuf.Empty\202\323\344\223\002E*C/managed-kafka/v1/clusters/{cluster_id}/connectors/{connector_name}'
  _globals['_CONNECTORSERVICE'].methods_by_name['Resume']._loaded_options = None
  _globals['_CONNECTORSERVICE'].methods_by_name['Resume']._serialized_options = b'\262\322*$\n\027ResumeConnectorMetadata\022\tConnector\202\323\344\223\002O\"J/managed-kafka/v1/clusters/{cluster_id}/connectors/resume/{connector_name}:\001*'
  _globals['_CONNECTORSERVICE'].methods_by_name['Pause']._loaded_options = None
  _globals['_CONNECTORSERVICE'].methods_by_name['Pause']._serialized_options = b'\262\322*#\n\026PauseConnectorMetadata\022\tConnector\202\323\344\223\002N\"I/managed-kafka/v1/clusters/{cluster_id}/connectors/pause/{connector_name}:\001*'
  _globals['_GETCONNECTORREQUEST']._serialized_start=292
  _globals['_GETCONNECTORREQUEST']._serialized_end=405
  _globals['_LISTCONNECTORSREQUEST']._serialized_start=407
  _globals['_LISTCONNECTORSREQUEST']._serialized_end=526
  _globals['_LISTCONNECTORSRESPONSE']._serialized_start=528
  _globals['_LISTCONNECTORSRESPONSE']._serialized_end=635
  _globals['_CREATECONNECTORREQUEST']._serialized_start=638
  _globals['_CREATECONNECTORREQUEST']._serialized_end=768
  _globals['_CREATECONNECTORMETADATA']._serialized_start=770
  _globals['_CREATECONNECTORMETADATA']._serialized_end=873
  _globals['_UPDATECONNECTORREQUEST']._serialized_start=876
  _globals['_UPDATECONNECTORREQUEST']._serialized_end=1119
  _globals['_UPDATECONNECTORMETADATA']._serialized_start=1121
  _globals['_UPDATECONNECTORMETADATA']._serialized_end=1238
  _globals['_DELETECONNECTORREQUEST']._serialized_start=1240
  _globals['_DELETECONNECTORREQUEST']._serialized_end=1356
  _globals['_DELETECONNECTORMETADATA']._serialized_start=1358
  _globals['_DELETECONNECTORMETADATA']._serialized_end=1427
  _globals['_RESUMECONNECTORREQUEST']._serialized_start=1429
  _globals['_RESUMECONNECTORREQUEST']._serialized_end=1545
  _globals['_RESUMECONNECTORMETADATA']._serialized_start=1547
  _globals['_RESUMECONNECTORMETADATA']._serialized_end=1650
  _globals['_PAUSECONNECTORREQUEST']._serialized_start=1652
  _globals['_PAUSECONNECTORREQUEST']._serialized_end=1767
  _globals['_PAUSECONNECTORMETADATA']._serialized_start=1769
  _globals['_PAUSECONNECTORMETADATA']._serialized_end=1871
  _globals['_CONNECTORSERVICE']._serialized_start=1874
  _globals['_CONNECTORSERVICE']._serialized_end=3320
# @@protoc_insertion_point(module_scope)
